@@ -20,10 +20,10 @@ setGeneric("quality",
 #'
 #' @section Rank based criteria:
 #'
-#' \code{Q_local}, \code{Q_global}, and \code{mean_R_nx} are
+#' \code{Q_local}, \code{Q_global}, and \code{mean_R_NX} are
 #' quality criteria based on the Co-ranking matrix.  \code{Q_local}
 #' and \code{Q_global} determine the local/global quality of the
-#' embedding, while \code{mean_R_nx} determines the quality of the
+#' embedding, while \code{mean_R_NX} determines the quality of the
 #' overall embedding. They are parameter free and return a single
 #' number. The object must include the original data.  The number
 #' returns is in the range [0, 1], higher values mean a better
@@ -192,7 +192,7 @@ setMethod(
 
         Kmax <- which.max(lcmc)
 
-        Qlocal <- sum(lcmc[1:Kmax]) / Kmax
+        Qlocal <- sum(Qnx[1:Kmax]) / Kmax
         return(as.vector(Qlocal))
     }
 )
@@ -228,7 +228,7 @@ setMethod(
 
         Kmax <- which.max(lcmc)
 
-        Qglobal <- sum(lcmc[(Kmax + 1):nQ]) / (N - Kmax)
+        Qglobal <- sum(Qnx[(Kmax + 1):nQ]) / (N - Kmax)
         return(Qglobal)
     }
 )
